from setuptools import setup, find_packages

setup(
    name="waterfountain",
    version="1.0",
    description="A useful library for all your waterfountain needs",
    packages=find_packages(),
    url="https://github.com/grihithmanchanda/waterfountain",
    license="MIT",
    install_requires=["requests"]
)